run_shell

Function run_shell 

pub fn run_shell(
    cmd: &str,
    path: &OsStr,
    relpath: &OsStr,
    bg: bool,
) -> Result<Option<ExitStatus>>
Run cmd through sh -c. The focused node’s action values are exported as $path and $relpath.

Foreground commands inherit the terminal and their exit status is returned; background commands are detached from stdio and None is returned.