pub struct ActionValues {
pub output: OsString,
pub alternate_output: OsString,
pub path: OsString,
pub relpath: OsString,
}Expand description
Values used when the focused node is accepted or passed to a shell binding.
Fields
output: OsStringText written to stdout when the node is accepted.
alternate_output: OsStringText written to stdout by the alternate accept action.
path: OsStringValue exported to shell bindings as $path.
relpath: OsStringValue exported to shell bindings as $relpath.
Implementations