Module tree

Module tree 

Source-neutral tree data consumed by the application and renderer.

Structs

ActionValues
Values used when the focused node is accepted or passed to a shell binding.
Node
Tree

Type Aliases

NodeId